@@ -14,7 +14,7 @@ use base qw(Verilog::Netlist::Subclass);
 use strict;
 use vars qw($Debug $Verbose $VERSION);
 
-$VERSION = '3.460';
+$VERSION = '3.478';
 
 ######################################################################
 #### Error Handling
@@ -529,15 +529,15 @@ The name of the preprocessor class. Defaults to "Verilog::Preproc".
 
 =item synthesis => $true_or_false
 
-With synthesis set, define SYNTHESIS, and ignore text bewteen "ambit",
+With synthesis set, define SYNTHESIS, and ignore text between "ambit",
 "pragma", "synopsys" or "synthesis" translate_off and translate_on meta
 comments.  Note using metacomments is discouraged as they have led to
 silicon bugs (versus ifdef SYNTHESIS); see
-L<http://www.veripool.org/papers/TenIPEdits_SNUGBos07_paper.pdf>.
+L<https://www.veripool.org/papers/TenIPEdits_SNUGBos07_paper.pdf>.
 
 =item use_pinselects => $true_or_false
 
-Indicates that bit selects should be parsed and intpreted.  False for
+Indicates that bit selects should be parsed and interpreted.  False for
 backward compatibility, but true recommended in new applications.
 
 =item use_vars => $true_or_false
@@ -694,11 +694,11 @@ Order based pin interconnect is not supported, use name based connections.
 
 =head1 DISTRIBUTION
 
-Verilog-Perl is part of the L<http://www.veripool.org/> free Verilog EDA
+Verilog-Perl is part of the L<https://www.veripool.org/> free Verilog EDA
 software tool suite.  The latest version is available from CPAN and from
-L<http://www.veripool.org/verilog-perl>.
+L<https://www.veripool.org/verilog-perl>.
 
-Copyright 2000-2019 by Wilson Snyder.  This package is free software; you
+Copyright 2000-2021 by Wilson Snyder.  This package is free software; you
 can redistribute it and/or modify it under the terms of either the GNU
 Lesser General Public License Version 3 or the Perl Artistic License Version 2.0.
 
@@ -717,9 +717,10 @@ L<Verilog::Netlist::ModPort>,
 L<Verilog::Netlist::Module>,
 L<Verilog::Netlist::Net>,
 L<Verilog::Netlist::Pin>,
+L<Verilog::Netlist::PinSelection>,
 L<Verilog::Netlist::Port>,
 L<Verilog::Netlist::Subclass>
 
-And the L<http://www.veripool.org/verilog-mode>Verilog-Mode package for Emacs.
+And the L<https://www.veripool.org/verilog-mode>Verilog-Mode package for Emacs.
 
 =cut
